"""
Name: UpdateACTExtensions.py
Date: 3/21/18
Author: Patrick Ly
Description: Replace obsolete methods in Extension-based python files with the 
corresponding overloaded methods.

Created For Python v2.7.15
"""
import re
import os
import glob
import fnmatch
import tempfile
import sys

def ObsoleteMethodReplacement(filename):
	file = open(filename, 'r+')
	temp = tempfile.TemporaryFile()
	wasModified = False

	# Searches for obsolete method usage, replaces them, and writes to temporary file
	for line in file:
		output = line

		if (re.search("ExtAPI.ExtensionManager.CurrentExtension", line) != None):
			pass

		elif (re.search("CreateLoadObject", line) != None or
				re.search("CreateResultObject", line) != None or
				re.search("CreateObject", line) != None or
				re.search("CreatePostObject", line) != None):
			line = line.rstrip()
			output = line[:-1] + ", ExtAPI.ExtensionManager.CurrentExtension)\n"
			wasModified = True

		elif (re.search(".LoadObjects", line) != None):
			output = line.replace(".LoadObjects", ".GetLoadObjects(ExtAPI.ExtensionManager.CurrentExtension)")
			wasModified = True

		elif (re.search(".ResultObjects", line) != None):
			output = line.replace(".ResultObjects", ".GetResultObjects(ExtAPI.ExtensionManager.CurrentExtension)")
			wasModified = True

		elif (re.search(".UserObjects", line) != None):
			output = line.replace(".UserObjects", ".GetUserObjects(ExtAPI.ExtensionManager.CurrentExtension)")
			wasModified = True

		temp.write(output)

	# Reset file pointers
	temp.seek(0)
	file.seek(0)

	# Write temporary file info into original file and close
	file.write(temp.read())
	file.close()
	temp.close()

	# Prints out the filename if it was modified
	if (wasModified):
		print(filename)

def main():
	# Recursively searches for python files in directory to modify
	for path, directories, filenames in os.walk(sys.argv[1]):
		for filename in fnmatch.filter(filenames, "*.py"):
			ObsoleteMethodReplacement(path + "\\" + filename)
	print("Files were successfully modified!")
	raw_input("Press Enter to Close...")

if __name__ == "__main__":
	main()
